import type { PathPrefix } from "./interface";
export declare const Utils: {
    /**
     * Helper function for encoding strings to hex
     *
     * @param string
     * @returns {string}
     */
    hexEncode(string: string): string;
    /**
     * Helper function for encoding strings to hex
     *
     * @param hexString string
     * @param encoding BufferEncoding
     * @returns {string}
     */
    hexDecode(hexString: string, encoding?: BufferEncoding): string;
    /**
     * Helper function to generate a random nonce
     *
     * @returns {string}
     */
    getRandomString(length?: number): string;
    /**
     * Test whether the given string is hex
     *
     * @param value any
     * @returns {boolean}
     */
    isHex(value: string): boolean;
    /**
     * Get a signing path from a hex number
     *
     * @param hexString {string}
     * @param hardened {boolean} Whether to return a hardened path
     * @returns {string}
     */
    getSigningPathFromHex(hexString: string, hardened?: boolean): string;
    /**
     * Increment that second to last part from the given part, set the last part to 0
     *
     * @param path string
     * @returns {*}
     */
    getNextIdentityPath(path: string): PathPrefix;
    /**
     * Increment that last part of the given path
     *
     * @param path string
     * @returns {*}
     */
    getNextPath(path: string): string;
};
